"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var rich_text_types__demo_1 = require("@contentful/rich-text-types--demo");
var index_1 = require("../index");
describe('documentToPlainTextString', function () {
    it('returns empty string when given an empty document', function () {
        var document = {
            nodeType: 'document',
            data: {},
            content: [],
        };
        expect(index_1.documentToPlainTextString(document)).toEqual('');
    });
    it('handles a simple case', function () {
        var document = {
            nodeType: 'document',
            data: {},
            content: [
                {
                    nodeType: rich_text_types__demo_1.BLOCKS.PARAGRAPH,
                    data: {},
                    content: [
                        {
                            nodeType: 'text',
                            data: {},
                            value: 'Trout is a',
                            marks: [],
                        },
                        {
                            nodeType: 'text',
                            data: {},
                            value: ' seafood d',
                            marks: [{ type: 'italic' }],
                        },
                        {
                            nodeType: 'text',
                            data: {},
                            value: 'elicacy.',
                            marks: [],
                        },
                    ],
                },
            ],
        };
        expect(index_1.documentToPlainTextString(document)).toEqual('Trout is a seafood delicacy.');
    });
    describe('rendering deeply nested documents', function () {
        var document = {
            nodeType: 'document',
            data: {},
            content: [
                {
                    nodeType: rich_text_types__demo_1.BLOCKS.PARAGRAPH,
                    data: {},
                    content: [
                        {
                            nodeType: rich_text_types__demo_1.BLOCKS.OL_LIST,
                            data: {},
                            content: [
                                {
                                    nodeType: rich_text_types__demo_1.BLOCKS.LIST_ITEM,
                                    data: {},
                                    content: [
                                        {
                                            nodeType: 'text',
                                            data: {},
                                            value: 'Trout is a',
                                            marks: [],
                                        },
                                        {
                                            nodeType: rich_text_types__demo_1.BLOCKS.UL_LIST,
                                            data: {},
                                            content: [
                                                {
                                                    nodeType: rich_text_types__demo_1.BLOCKS.LIST_ITEM,
                                                    data: {},
                                                    content: [
                                                        {
                                                            nodeType: 'text',
                                                            data: {},
                                                            value: 'seafood d',
                                                            marks: [{ type: 'italic' }],
                                                        },
                                                        {
                                                            nodeType: 'text',
                                                            data: {},
                                                            value: 'elicacy.',
                                                            marks: [],
                                                        },
                                                    ],
                                                },
                                            ],
                                        },
                                    ],
                                },
                            ],
                        },
                    ],
                },
                {
                    nodeType: rich_text_types__demo_1.BLOCKS.HR,
                    data: {},
                    content: [],
                },
                {
                    nodeType: rich_text_types__demo_1.BLOCKS.PARAGRAPH,
                    data: {},
                    content: [
                        {
                            nodeType: 'text',
                            data: {},
                            value: 'It is scrumptious.',
                            marks: [],
                        },
                    ],
                },
            ],
        };
        it('handles nested nodes gracefully', function () {
            expect(index_1.documentToPlainTextString(document)).toEqual('Trout is a seafood delicacy. It is scrumptious.');
        });
        it('defers to the user-supplied block divisor', function () {
            expect(index_1.documentToPlainTextString(document, '\n\n')).toEqual('Trout is a seafood delicacy.\n\nIt is scrumptious.');
        });
    });
});
//# sourceMappingURL=index.test.js.map